@@ -141,7 +141,7 @@ class SpineAnimationData(SpineData):
                     if image_path is not None:
                         removed_attachments.setdefault(attachment_id, {})
                         removed_attachments[attachment_id][slot_id] = image_path
-                elif isinstance(slot_data, SkinMesh):
+                elif isinstance(slot_data, (SkinMesh, SkinLinkedMesh)):
                     mesh_image_path = slot_data.path or slot_data.name
                     removed_images.append(mesh_image_path)
                 elif hasattr(slot_data, "path") and slot_data.path is not None:
@@ -204,9 +204,9 @@ class SpineAnimationData(SpineData):
         for slot_id, slot_data in anim_slots.items():
             # By default we have to add the slot attachment base data as they are normally missing
             # in the json info for optimization
-            slot_used_attachments = slot_data.get_used_attachments() + [
-                slots_dict[slot_id].attachment
-            ]
+            slot_used_attachments = slot_data.get_used_attachments()
+            if slots_dict[slot_id].attachment is not None:
+                slot_used_attachments.append(slots_dict[slot_id].attachment)
 
             # Discarding slot if:
             # 1 -) At least 1 animation it is not empty
